@@ -13,65 +13,52 @@
 #' asset returns
 #' @param Rf the risk free rate
 #' @param \dots any other passthru parameters
-#' @author Matthieu Lestel
-#' @references Carl Bacon, \emph{Practical portfolio performance measurement 
+#' @author Matthieu Lestel, Brian G. Peterson
+#' @seealso \code{\link{SharpeRatio.annualized}}
+#' @references 
+#' 
+#' Carl Bacon, \emph{Practical portfolio performance measurement 
 #' and attribution}, second edition 2008 p.99
 #' 
+#' Pezier, Jaques and White, Anthony. 2006. The Relative Merits of Investable 
+#' Hedge Fund Indices and of Funds of Hedge Funds in Optimal Passive Portfolios.
+#' \url{http://econpapers.repec.org/paper/rdgicmadp/icma-dp2006-10.htm}
+#' 
 ###keywords ts multivariate distribution models
 #' @examples
 #' data(portfolio_bacon)
-#' print(AdjustedSharpeRatio(portfolio_bacon[,1])) #expected 0.81
+#' print(AdjustedSharpeRatio(portfolio_bacon[,1])) #expected 0.7591435
 #'
 #' data(managers)
 #' print(AdjustedSharpeRatio(managers['1996']))
-#' print(AdjustedSharpeRatio(managers['1996',1])) 
-#'
-#' @export 
-
+#' @export
 AdjustedSharpeRatio <- function (R, Rf = 0, ...)
 {
-    R = checkData(R)
-
-    if (ncol(R)==1 || is.null(R) || is.vector(R)) {
-       calcul = FALSE
-        for (i in (1:length(R))) {
-     	     if (!is.na(R[i])) {
-     	    	calcul = TRUE
-	     }
-        }		      
-        if(!calcul) {
-	  result = NA
-	}
-	else {
-	     period = Frequency(R)
-             R = na.omit(R)
-       	     n = length(R)
-       	     Rp = (prod(1+R/100)^(period/length(R))-1)*100
-       	     Sigp = sqrt(sum((R-mean(R))^2)/n)*sqrt(period)
-       	     SR = (Rp - Rf) / Sigp
-       	     K = kurtosis(R, method = "moment")
-       	     S = skewness(R)
-       	     result = SR*(1+(S/6)*SR-((K-3)/24)*SR^2)
-        }
-       return(result)
-    }  
-    else {
-        result = apply(R, MARGIN = 2, AdjustedSharpeRatio, Rf = Rf, period = period, ...)
-        result<-t(result)
-        colnames(result) = colnames(R)
-        rownames(result) = paste("Adjusted Sharpe ratio (Risk free = ",Rf,")", sep="")
-        return(result)
-    }
+  if (ncol(R)==1 || is.null(R) || is.vector(R)) {
+    R = na.omit(R)
+    if(length(R)<2) return(NA)
+    SR = SharpeRatio.annualized(R, Rf, ...)
+    K = kurtosis(R, method = "moment")
+    S = skewness(R)
+    result = SR*(1+(S/6)*SR-((K-3)/24)*SR^2)
+    return(result)
+  } else {
+    result = apply(R, MARGIN = 2, AdjustedSharpeRatio, Rf = Rf, ...)
+    result<-t(result)
+    colnames(result) = colnames(R)
+    rownames(result) = paste("Adjusted Sharpe ratio (Risk free = ",Rf,")", sep="")
+    return(result)
+  }
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: AdjustedSharpeRatio.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
