@@ -138,12 +138,11 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
             },
             interp = {
 
-                # require("Hmisc")
-                # stopifnot("package:Hmisc" %in% search() || require("Hmisc",quietly=TRUE))
+                stopifnot(requireNamespace("Hmisc",quietly=TRUE))
                 a = min(x)
                 b = max(x)
 
-                xcdf = Hmisc::Ecdf.default(x, pl=FALSE)
+                xcdf = Hmisc::Ecdf(x, pl=FALSE)
                 f <- approxfun(xcdf$x,xcdf$y,method="linear",ties="ordered")
 
                 if(output == "full") {
@@ -184,11 +183,11 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: Omega.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
