@@ -88,16 +88,13 @@ function(Ra, Rb, method = c("Capture","Number","Percent"), side = c("Up","Down")
         if(method == "Capture" & side == "Up") {
             UpRa = subset(merged.assets[,1], merged.assets[,2] > 0)
             UpRb = subset(merged.assets[,2], merged.assets[,2] > 0)
-            cumRa = sum(UpRa)
-            cumRb = sum(UpRb)
-            result = cumRa/cumRb
+            #Bacon defines this as a ratio of means, but the ratio of sums and means is the same, and this is more efficient
+            result = sum(UpRa)/sum(UpRb)
         }
         if(method == "Capture" & side == "Down") {
             DnRa = subset(merged.assets[,1], merged.assets[,2] <= 0)
             DnRb = subset(merged.assets[,2], merged.assets[,2] <= 0)
-            cumRa = sum(DnRa)
-            cumRb = sum(DnRb)
-            result = cumRa/cumRb
+            result = sum(DnRa)/sum(DnRb)
         }
 
         if(method == "Number" & side == "Up") {
@@ -142,11 +139,11 @@ function(Ra, Rb, method = c("Capture","Number","Percent"), side = c("Up","Down")
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: UpDownRatios.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
