@@ -55,7 +55,6 @@
 #' \code{\link{plot}}
 #' @references main code forked/borrowed/ported from the excellent: \cr Fox,
 #' John (2007) \emph{car: Companion to Applied Regression} \cr
-#' \url{http://www.r-project.org},
 #' \url{http://socserv.socsci.mcmaster.ca/jfox/}
 ###keywords ts multivariate distribution models hplot
 #' @examples
@@ -93,7 +92,7 @@
 #' }
 #' #end examples
 #' 
-#' @export 
+#' @export
 chart.QQPlot <-
 function(R, distribution="norm", ylab=NULL,
         xlab=paste(distribution, "Quantiles"), main=NULL, las=par("las"),
@@ -144,7 +143,7 @@ function(R, distribution="norm", ylab=NULL,
         abline(a, b, col=col[2], lwd=lwd)
         }
     if (line=="robust"){
-        stopifnot("package:MASS" %in% search() || require("MASS",quietly=TRUE))
+        stopifnot(requireNamespace("MASS",quietly=TRUE))
         coef<-coefficients(MASS::rlm(ord.x~z))
         a<-coef[1]
         b<-coef[2]
@@ -225,11 +224,11 @@ function(R, distribution="norm", ylab=NULL,
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2018 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.QQPlot.R 3528 2014-09-11 12:43:17Z braverock $
+# $Id$
 #
 ###############################################################################
